abacusai.api_class.ai_agents — AbacusAI documentation

# `abacusai.api_class.ai_agents`

## Module Contents

### Classes

`FieldDescriptor` | Configs for vector store indexing.

class abacusai.api_class.ai_agents.FieldDescriptor

  Bases: `abacusai.api_class.abstract.ApiClass`

  Configs for vector store indexing.

  Parameters:

    - field (str) – The field to be extracted. This will be used as the key in the response.

    - description (str) – The description of this field. If not included, the response_field will be used.

    - example_extraction (Union[str, int, bool, float]) – An example of this extracted field.

    - type (enums.FieldDescriptorType) – The type of this field. If not provided, the default type is STRING.

  field: str
  description: str
  example_extraction: str | int | bool | float | list | dict
  type: abacusai.api_class.enums.FieldDescriptorType